@@ -3,6 +3,8 @@
 ROOT=$(cd "$(dirname "$0")/../" && pwd)
 
 if [[ $# -eq 0 ]]; then
+    $0 5.36.0 5-36 x86_64
+    $0 5.36.0 5-36 arm64
     $0 5.34.1 5-34 x86_64
     $0 5.34.1 5-34 arm64
     $0 5.32.1 5-32 x86_64
